@@ -6,7 +6,7 @@ from datetime import datetime, timedelta
 from blueflask.lib.errors import internal_error, bad_request, not_found
 from blueflask.lib.infos import success
 
-from ...consts import CONFIG, SERVICE_CODE
+from ...consts import CONFIG, SERVICE_CODE, LOGS
 from . import api
 from ... import getsms as lib_customer
 
@@ -78,26 +78,36 @@ def send_sms():
     headers = request.headers or {}
     json_doc = request.get_json() or {}
     msisdn = json_doc["msisdn"]
-    if (msisdn[-9:]).startswith("34"):
+
+    telma = (msisdn[-9:]).startswith("34")
+
+    if telma:
+        LOGS.logger.info("MSISDN Telma redirected to Orange SMPP.")
         queue = CONFIG['orange']['account']
+    elif not telma and json_doc.get('sender_id') == 'orange':
+        LOGS.logger.warning(
+            "MSISDN is not Telma but targeting Orange SMPP. "
+            "Redirected to default SMPP."
+        )
+        queue = CONFIG['Blueline']['account']
     else:
         if user.startswith('partenaire'):
-            sender_id = user.split('_')[1]
+                sender_id = user.split('_')[1]
         else:
             sender_id = json_doc.get('sender_id', 'bip')
-        try:
-            logging.warn(sender_id)
-            json_doc['sender_id'] = sender_id
-            queue = CONFIG[sender_id]['account']
-        except KeyError:
-            return bad_request(
-                message="Le sender_id n'exist pas",
-                code='{}-{}'.format(
-                    SERVICE_CODE,
-                    '4001'
-                    ),
-                service_code=SERVICE_CODE
-                )
+            try:
+                logging.warn(sender_id)
+                json_doc['sender_id'] = sender_id
+                queue = CONFIG[sender_id]['account']
+            except KeyError:
+                return bad_request(
+                    message="Le sender_id n'exist pas",
+                    code='{}-{}'.format(
+                        SERVICE_CODE,
+                        '4001'
+                        ),
+                    service_code=SERVICE_CODE
+                    )
     document = {
         'auth': auth or (),
         'params': params,
